@@ -93,9 +93,11 @@ feer_tls_create_context(pTHX_ const char *cert_file, const char *key_file, int h
     ctx->random_bytes = ptls_openssl_random_bytes;
     ctx->get_time = &ptls_get_time;
 
-    /* Key exchange: X25519 + secp256r1 */
+    /* Key exchange: X25519 (not available on LibreSSL) + secp256r1 */
     static ptls_key_exchange_algorithm_t *key_exchanges[] = {
+#if PTLS_OPENSSL_HAVE_X25519
         &ptls_openssl_x25519,
+#endif
         &ptls_openssl_secp256r1,
         NULL
     };
