@@ -217,13 +217,13 @@ input body handler (psgi.input), it is advised to close it after read is done
 
 Returns a hash reference of headers in form of { name => value, ... }.
 
-normalization_style is one of:
+normalization_style is one of (always use named constants, not numeric values):
 
-0 - skip normalization (default)
-HEADER_NORM_LOCASE - "content-type"
-HEADER_NORM_UPCASE - "CONTENT-TYPE"
-HEADER_NORM_LOCASE_DASH - "content_type"
-HEADER_NORM_UPCASE_DASH - "CONTENT_TYPE" (like PSGI, but without "HTTP_" prefix)
+HEADER_NORM_SKIP (0) - skip normalization (default)
+HEADER_NORM_UPCASE_DASH (1) - "CONTENT_TYPE" (like PSGI, but without "HTTP_" prefix)
+HEADER_NORM_LOCASE_DASH (2) - "content_type"
+HEADER_NORM_UPCASE (3) - "CONTENT-TYPE"
+HEADER_NORM_LOCASE (4) - "content-type"
 
 One can export these constants via C<< use Feersum 'HEADER_NORM_LOCASE' >>
 
