@@ -155,13 +155,17 @@ A reference to the writer is passed in as the first and only argument to the
 sub.  It's recommended that you use C<$_[0]> rather than closing-over on C<$w>
 to prevent a circular reference.
 
-=item C<< $w->sendfile($fh) >>
+=item C<< $w->sendfile($fh [, $offset, $length]) >>
 
 Send file contents using zero-copy sendfile(2) system call. Linux only.
 The file handle should be a regular file opened for reading. The response
-should have a Content-Length header set to the file size. After calling
+should have a Content-Length header set appropriately. After calling
 sendfile(), call C<close()> on the writer.
 
+Optional C<$offset> (bytes to skip from start, default 0) and C<$length>
+(bytes to send, default remainder of file) allow sending a portion of
+the file.
+
 B<Note:> Not supported for HTTP/2 responses. Use C<write()> instead.
 
     my $w = $req->start_streaming(200, [
